@@ -1256,6 +1256,7 @@ first_names = [
 ('撼', 1),
 ]
 
+last_names.sort(key=lambda x: x[1])
 last_names_choices = list("".join([name[0] * name[1] for name in last_names]))
 random.shuffle(last_names_choices)
 random.shuffle(last_names_choices)
@@ -1276,3 +1277,17 @@ def get_last_names():
 
 def get_suggest_first_names():
     return [x[0] for x in first_names]
+
+
+def guess_surname(fullname):
+    sns = []
+    for sn, _ in last_names:
+        if fullname.startswith(sn):
+            sns.append(sn)
+    final_sn = ""
+    for sn in sns:
+        if len(sn) > len(final_sn):
+            final_sn = sn
+    if final_sn:
+        return final_sn
+    return fullname.split()[-1]
